@@ -25,6 +25,7 @@ class MikrotikApiError(Exception):
 
 class MikrotikApiClient:
     """Query the Mikrotik API"""
+    _ssl_context = None
 
     def __init__(self,
                  host,
@@ -33,24 +34,34 @@ class MikrotikApiClient:
                  enable_ssl=False,
                  port=None,
                  timeout=30,
+                 ignore_permissions=False,
+                 ignore_internal_errors=False,
                  record=False):
         self.host = host
         self.port = port or (8729 if enable_ssl else 8728)
         self._user = username
         self._pass = password
         self._timeout = timeout
+        self._ignore_internal_errors = ignore_internal_errors
+        self._ignore_permissions = ignore_permissions
         self._logged_in = False
         self._reader = None
         self._writer = None
         self._ssl = None
         self.record = [] if record else None
+
         if enable_ssl:
-            self._ssl = ssl.create_default_context()
-            self._ssl.check_hostname = False
-            self._ssl.verify_mode = ssl.CERT_NONE
-            self._ssl.set_ciphers('ALL:@SECLEVEL=0')
+            if not MikrotikApiClient._ssl_context:
+                # PPA-1362 Change the way sslctx is configured
+                sslctx = MikrotikApiClient._ssl_context = ssl.create_default_context()
+                sslctx.check_hostname = False
+                sslctx.verify_mode = ssl.CERT_NONE
+                sslctx.set_ciphers('ALL:@SECLEVEL=0')
+            self._ssl = MikrotikApiClient._ssl_context
+
         # map to filter special chars in api keys
         self.trans_map = str.maketrans('-', '_', './')
+        self.error = None  # this will be set if we hit an error we can continue from
 
     async def _get_results_data(self,
                                 cmd,
@@ -119,6 +130,23 @@ class MikrotikApiClient:
                 await self.close()
                 raise
             except Exception as e:
+                if isinstance(e, MikrotikApiError):
+                    if 'not enough permissions' in str(e):
+                        self.error = e
+                        if self._ignore_permissions:
+                            logging.info(
+                                'Not enough permissions for "%s" on %s, returning empty result.',
+                                cmd, self.host)
+                            return []  # just return empty results
+                        raise  # no need to retry this
+                    elif 'contact MikroTik support' in str(e):
+                        self.error = e
+                        if self._ignore_internal_errors:
+                            logging.info(
+                                '%s running command "%s" on %s, returning empty result.',
+                                e, cmd, self.host)
+                            return []  # just return empty results
+                        raise  # no need to retry this
                 logging.info('Error calling "%s" on host %s: %s (%s)', cmd, self.host,
                              type(e).__name__, e)
                 err = e
@@ -234,8 +262,6 @@ class MikrotikApiClient:
                 return r
             r.append(w)
 
-    _masks = [0x80, 0xc0, 0xe0, 0xf0]
-
     async def read_word(self):
         """Read a string from the server."""
         # length
@@ -243,10 +269,19 @@ class MikrotikApiClient:
         if not buf:  # disconnected
             await self.close()
             raise MikrotikApiError('Connection closed by remote end')
-        for i, mask in enumerate(self._masks):
-            if (ord(buf) & mask) != mask:
-                buf = struct.pack('B', ord(buf) & ~mask)
-                break
+        byte_value = buf[0]
+        if (byte_value & 0x80) != 0x80:
+            buf = bytes([byte_value & ~0x80])
+            i = 0
+        elif (byte_value & 0xC0) != 0xC0:
+            buf = bytes([byte_value & ~0xC0])
+            i = 1
+        elif (byte_value & 0xE0) != 0xE0:
+            buf = bytes([byte_value & ~0xE0])
+            i = 2
+        elif (byte_value & 0xF0) != 0xF0:
+            buf = bytes([byte_value & ~0xF0])
+            i = 3
         else:
             buf = b''
             i = 4
