@@ -344,6 +344,11 @@ class Link(BaseWrapperClass):
         if value is not None:
             self.pb.poller_hash = value
 
+    def add_bridged_mac(self, mac):
+        if mac.startswith('33:33:') or mac == '00:00:00:00:00:00':
+            return  # ignore IPv6 multicast MACs (PPA-1321) and zero MACs
+        self.bridged_mac_addresses.append(mac)
+
 
 @pb_wrapper(network_poller_pb2.NetworkElement.WirelessLink)
 class WirelessLink(BaseWrapperClass):
@@ -661,6 +666,124 @@ class RadioStream(BaseWrapperClass):
             self.pb.ClearField('noise_floor')
 
 
+@pb_wrapper(network_poller_pb2.NetworkElement.RfAggregationGroup)
+class RfAggregationGroup(BaseWrapperClass):
+
+    def __init__(self, pb=None, errctx=None, **kwargs):
+        super().__init__(pb, errctx)
+        for key, value in kwargs.items():
+            setattr(self, key, value)
+
+    @property
+    def name(self):
+        return self.pb.name if self.pb.HasField('name') else None
+
+    @name.setter
+    def name(self, value):
+        if value:
+            self.pb.name = value
+        else:
+            self.pb.ClearField('name')
+
+    @property
+    def airtime(self):
+        return self.pb.airtime if self.pb.HasField('airtime') else None
+
+    @airtime.setter
+    def airtime(self, value):
+        if value is not None:
+            if value >= 0:
+                self.pb.airtime = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.RfAggregationGroup.airtime',
+                    value=value,
+                    metric_name='NetworkElement.RfAggregationGroup.airtime')
+        else:
+            self.pb.ClearField('airtime')
+
+    @property
+    def tx_packet_error_rate(self):
+        return self.pb.tx_packet_error_rate if self.pb.HasField(
+            'tx_packet_error_rate') else None
+
+    @tx_packet_error_rate.setter
+    def tx_packet_error_rate(self, value):
+        if value is not None:
+            if value >= 0:
+                self.pb.tx_packet_error_rate = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.RfAggregationGroup.tx_packet_error_rate',
+                    value=value,
+                    metric_name='NetworkElement.RfAggregationGroup.tx_packet_error_rate'
+                )
+        else:
+            self.pb.ClearField('tx_packet_error_rate')
+
+    @property
+    def rx_packet_error_rate(self):
+        return self.pb.rx_packet_error_rate if self.pb.HasField(
+            'rx_packet_error_rate') else None
+
+    @rx_packet_error_rate.setter
+    def rx_packet_error_rate(self, value):
+        if value is not None:
+            if value >= 0:
+                self.pb.rx_packet_error_rate = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.RfAggregationGroup.rx_packet_error_rate',
+                    value=value,
+                    metric_name='NetworkElement.RfAggregationGroup.rx_packet_error_rate'
+                )
+        else:
+            self.pb.ClearField('rx_packet_error_rate')
+
+    @property
+    def tx_interference_signal_ratio(self):
+        return self.pb.tx_interference_signal_ratio if self.pb.HasField(
+            'tx_interference_signal_ratio') else None
+
+    @tx_interference_signal_ratio.setter
+    def tx_interference_signal_ratio(self, value):
+        if value is not None:
+            if value >= -150 and value <= 150:
+                self.pb.tx_interference_signal_ratio = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.RfAggregationGroup.tx_interference_signal_ratio',
+                    value=value,
+                    metric_name=
+                    'NetworkElement.RfAggregationGroup.tx_interference_signal_ratio')
+        else:
+            self.pb.ClearField('tx_interference_signal_ratio')
+
+    @property
+    def rx_interference_signal_ratio(self):
+        return self.pb.rx_interference_signal_ratio if self.pb.HasField(
+            'rx_interference_signal_ratio') else None
+
+    @rx_interference_signal_ratio.setter
+    def rx_interference_signal_ratio(self, value):
+        if value is not None:
+            if value >= -150 and value <= 150:
+                self.pb.rx_interference_signal_ratio = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.RfAggregationGroup.rx_interference_signal_ratio',
+                    value=value,
+                    metric_name=
+                    'NetworkElement.RfAggregationGroup.rx_interference_signal_ratio')
+        else:
+            self.pb.ClearField('rx_interference_signal_ratio')
+
+
 @pb_wrapper(network_poller_pb2.NetworkElement.Radio)
 class Radio(BaseWrapperClass):
 
@@ -995,6 +1118,77 @@ class Radio(BaseWrapperClass):
                             value=value,
                             metric_name='NetworkElement.Radio.max_distance')
 
+    @property
+    def rx_path_loss(self):
+        return self.pb.rx_path_loss if self.pb.HasField('rx_path_loss') else None
+
+    @rx_path_loss.setter
+    def rx_path_loss(self, value):
+        if value is not None:
+            if value >= -150 and value <= 150:
+                self.pb.rx_path_loss = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.Radio.rx_path_loss',
+                                value=value,
+                                metric_name='NetworkElement.Radio.rx_path_loss')
+        else:
+            self.pb.ClearField('rx_path_loss')
+
+    @property
+    def rx_max_interference_noise_ratio(self):
+        return self.pb.rx_max_interference_noise_ratio if self.pb.HasField(
+            'rx_max_interference_noise_ratio') else None
+
+    @rx_max_interference_noise_ratio.setter
+    def rx_max_interference_noise_ratio(self, value):
+        if value is not None:
+            if value >= -150 and value <= 150:
+                self.pb.rx_max_interference_noise_ratio = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.Radio.rx_max_interference_noise_ratio',
+                    value=value,
+                    metric_name='NetworkElement.Radio.rx_max_interference_noise_ratio')
+        else:
+            self.pb.ClearField('rx_max_interference_noise_ratio')
+
+    @property
+    def rx_max_sensitivity_loss(self):
+        return self.pb.rx_max_sensitivity_loss if self.pb.HasField(
+            'rx_max_sensitivity_loss') else None
+
+    @rx_max_sensitivity_loss.setter
+    def rx_max_sensitivity_loss(self, value):
+        if value is not None:
+            if value >= -150 and value <= 150:
+                self.pb.rx_max_sensitivity_loss = value
+            elif self.errctx:
+                self.errctx.add(
+                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                    'Invalid value for NetworkElement.Radio.rx_max_sensitivity_loss',
+                    value=value,
+                    metric_name='NetworkElement.Radio.rx_max_sensitivity_loss')
+        else:
+            self.pb.ClearField('rx_max_sensitivity_loss')
+
+    @property
+    def azimuth(self):
+        return self.pb.azimuth if self.pb.HasField('azimuth') else None
+
+    @azimuth.setter
+    def azimuth(self, value):
+        if value is None:
+            self.pb.ClearField('azimuth')
+        elif value >= 0 and value <= 360:
+            self.pb.azimuth = value
+        elif self.errctx:
+            self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                            'Invalid value for NetworkElement.Radio.azimuth',
+                            value=value,
+                            metric_name='NetworkElement.Radio.azimuth')
+
 
 @pb_wrapper(network_poller_pb2.NetworkElement.Sector)
 class Sector(BaseWrapperClass):
@@ -1323,6 +1517,9 @@ class Interface(BaseWrapperClass):
         self.radios = Repeated(Radio, self.pb.radios, self.errctx)
         self.sectors = Repeated(Sector, self.pb.sectors, self.errctx)
         self.pons = Repeated(Pon, self.pb.pons, self.errctx)
+        self.rf_aggregation_groups = Repeated(RfAggregationGroup,
+                                              self.pb.rf_aggregation_groups,
+                                              self.errctx)
         for key, value in kwargs.items():
             setattr(self, key, value)
 
@@ -1657,6 +1854,11 @@ class Interface(BaseWrapperClass):
         else:
             self.pb.ClearField('model')
 
+    def add_bridged_mac(self, mac):
+        if mac.startswith('33:33:') or mac == '00:00:00:00:00:00':
+            return  # ignore IPv6 multicast MACs (PPA-1321) and zero MACs
+        self.bridged_mac_addresses.append(mac)
+
 
 @pb_wrapper(network_poller_pb2.IpMac)
 class IpMac(BaseWrapperClass):
