@@ -1008,6 +1008,57 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(len(radio.errctx.errors), 2)
         radio.errctx = None
 
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.rx_path_loss, None)
+        radio.rx_path_loss = -20.59
+        self.assertEqual(round(radio.rx_path_loss, 4), -20.59)
+        radio.rx_path_loss = 190.59
+        self.assertEqual(round(radio.rx_path_loss, 4), -20.59)
+        radio.rx_path_loss = None
+        self.assertEqual(radio.rx_path_loss, None)
+        self.assertEqual(len(radio.errctx.errors), 1)
+        radio.errctx = None
+
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.rx_max_interference_noise_ratio, None)
+        radio.rx_max_interference_noise_ratio = -20.59
+        self.assertEqual(round(radio.rx_max_interference_noise_ratio, 4), -20.59)
+        radio.rx_max_interference_noise_ratio = 190.59
+        self.assertEqual(round(radio.rx_max_interference_noise_ratio, 4), -20.59)
+        radio.rx_max_interference_noise_ratio = None
+        self.assertEqual(radio.rx_max_interference_noise_ratio, None)
+        self.assertEqual(len(radio.errctx.errors), 1)
+        radio.errctx = None
+
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.rx_max_sensitivity_loss, None)
+        radio.rx_max_sensitivity_loss = -20.59
+        self.assertEqual(round(radio.rx_max_sensitivity_loss, 4), -20.59)
+        radio.rx_max_sensitivity_loss = 190.59
+        self.assertEqual(round(radio.rx_max_sensitivity_loss, 4), -20.59)
+        radio.rx_max_sensitivity_loss = None
+        self.assertEqual(radio.rx_max_sensitivity_loss, None)
+        self.assertEqual(len(radio.errctx.errors), 1)
+        radio.errctx = None
+
+        radio.errctx = network_element_update.ErrorContext()
+        self.assertEqual(radio.azimuth, None)
+        radio.azimuth = 0
+        self.assertEqual(round(radio.azimuth, 4), 0)
+        radio.azimuth = 180.5
+        self.assertEqual(round(radio.azimuth, 4), 180.5)
+        radio.max_distance = -1
+        self.assertEqual(round(radio.azimuth, 4), 180.5)
+        radio.azimuth = 360
+        self.assertEqual(round(radio.azimuth, 4), 360)
+        radio.azimuth = 361
+        self.assertEqual(round(radio.azimuth, 4), 360)
+        radio.azimuth = None
+        self.assertEqual(radio.azimuth, None)
+        self.assertEqual(len(radio.errctx.errors), 2)
+        radio.errctx = None
+
+
         # RadioStream
         stream = radio.streams.add()
         stream.id = '1'
@@ -1207,6 +1258,74 @@ class TestNetworkElementUpdate(unittest.TestCase):
         wlink.poller_hash = poller_hash
         self.assertEqual(poller_hash, wlink.poller_hash)
 
+
+        # RfAggregationGroup
+        rf_aggr_gr = intf.rf_aggregation_groups.add()
+        rf_aggr_gr.name = 'RadioGr1'
+        self.assertEqual(rf_aggr_gr.name, 'RadioGr1')
+
+
+        rf_aggr_gr.errctx = network_element_update.ErrorContext()
+        self.assertEqual(rf_aggr_gr.airtime, None)
+        rf_aggr_gr.airtime = 19.2
+        self.assertEqual(round(rf_aggr_gr.airtime, 4), 19.2)
+        rf_aggr_gr.airtime = -1
+        self.assertEqual(round(rf_aggr_gr.airtime, 4), 19.2)
+        rf_aggr_gr.airtime = 100.1
+        self.assertEqual(round(rf_aggr_gr.airtime, 4), 100.1)
+        rf_aggr_gr.airtime = None
+        self.assertEqual(rf_aggr_gr.airtime, None)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        rf_aggr_gr.errctx = None
+
+        rf_aggr_gr.errctx = network_element_update.ErrorContext()
+        self.assertEqual(rf_aggr_gr.tx_packet_error_rate, None)
+        rf_aggr_gr.tx_packet_error_rate = 19.2
+        self.assertEqual(round(rf_aggr_gr.tx_packet_error_rate, 4), 19.2)
+        rf_aggr_gr.tx_packet_error_rate = -1
+        self.assertEqual(round(rf_aggr_gr.tx_packet_error_rate, 4), 19.2)
+        rf_aggr_gr.tx_packet_error_rate = 100.1
+        self.assertEqual(round(rf_aggr_gr.tx_packet_error_rate, 4), 100.1)
+        rf_aggr_gr.tx_packet_error_rate = None
+        self.assertEqual(rf_aggr_gr.tx_packet_error_rate, None)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        rf_aggr_gr.errctx = None
+
+        rf_aggr_gr.errctx = network_element_update.ErrorContext()
+        self.assertEqual(rf_aggr_gr.rx_packet_error_rate, None)
+        rf_aggr_gr.rx_packet_error_rate = 19.2
+        self.assertEqual(round(rf_aggr_gr.rx_packet_error_rate, 4), 19.2)
+        rf_aggr_gr.rx_packet_error_rate = -1
+        self.assertEqual(round(rf_aggr_gr.rx_packet_error_rate, 4), 19.2)
+        rf_aggr_gr.rx_packet_error_rate = 100.1
+        self.assertEqual(round(rf_aggr_gr.rx_packet_error_rate, 4), 100.1)
+        rf_aggr_gr.rx_packet_error_rate = None
+        self.assertEqual(rf_aggr_gr.rx_packet_error_rate, None)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        rf_aggr_gr.errctx = None
+
+        rf_aggr_gr.errctx = network_element_update.ErrorContext()
+        self.assertEqual(rf_aggr_gr.tx_interference_signal_ratio, None)
+        rf_aggr_gr.tx_interference_signal_ratio = -20.59
+        self.assertEqual(round(rf_aggr_gr.tx_interference_signal_ratio, 4), -20.59)
+        rf_aggr_gr.tx_interference_signal_ratio = 190.59
+        self.assertEqual(round(rf_aggr_gr.tx_interference_signal_ratio, 4), -20.59)
+        rf_aggr_gr.tx_interference_signal_ratio = None
+        self.assertEqual(rf_aggr_gr.tx_interference_signal_ratio, None)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        rf_aggr_gr.errctx = None
+
+        rf_aggr_gr.errctx = network_element_update.ErrorContext()
+        self.assertEqual(rf_aggr_gr.rx_interference_signal_ratio, None)
+        rf_aggr_gr.rx_interference_signal_ratio = -20.59
+        self.assertEqual(round(rf_aggr_gr.rx_interference_signal_ratio, 4), -20.59)
+        rf_aggr_gr.rx_interference_signal_ratio = 190.59
+        self.assertEqual(round(rf_aggr_gr.rx_interference_signal_ratio, 4), -20.59)
+        rf_aggr_gr.rx_interference_signal_ratio = None
+        self.assertEqual(rf_aggr_gr.rx_interference_signal_ratio, None)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        rf_aggr_gr.errctx = None
+
         # Sector
         sector = intf.sectors.add()
 
@@ -1472,3 +1591,27 @@ class TestNetworkElementUpdate(unittest.TestCase):
         self.assertEqual(ponlink.tx_link_rate, None)
         self.assertEqual(len(ponlink.errctx.errors), 2)
         ponlink.errctx = None
+
+    def test_add_bridged_mac(self):
+        """PPA-1321 test MAC filtering when adding bridged macs via a helper method."""
+        neu = network_element_update.NetworkElementUpdate()
+        intf = neu.data.interfaces.add()
+        link = intf.links.add()
+
+        intf.add_bridged_mac('00:01:02:03:04:05')
+        intf.add_bridged_mac('33:33:ff:00:00:00')  # should be filtered
+        intf.add_bridged_mac('00:00:00:00:00:00')  # should be filtered
+        intf.add_bridged_mac('00:01:02:03:04:06')
+        link.add_bridged_mac('00:01:02:03:04:05')
+        link.add_bridged_mac('33:33:ff:00:00:00')  # should be filtered
+        link.add_bridged_mac('00:00:00:00:00:00')  # should be filtered
+        link.add_bridged_mac('00:01:02:03:04:06')
+
+        self.assertEqual(len(intf.bridged_mac_addresses), 2)
+        self.assertEqual(intf.bridged_mac_addresses[0], '00:01:02:03:04:05')
+        self.assertEqual(intf.bridged_mac_addresses[1], '00:01:02:03:04:06')
+
+        self.assertEqual(len(link.bridged_mac_addresses), 2)
+        self.assertEqual(link.bridged_mac_addresses[0], '00:01:02:03:04:05')
+        self.assertEqual(link.bridged_mac_addresses[1], '00:01:02:03:04:06')
+
